@@ -28,7 +28,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 	image_min_dimensions
 );
 
-$VERSION = 1.2;
+$VERSION = 1.22;
 
 sub file_format {
 	my %params = @_;
@@ -103,14 +103,18 @@ sub valid_file_format {
         # Work around a bug in File::MMagic (RT#12074)
         seek($fh,0,0);
 
+    # File::MMagic returns 'application/octet-stream" as a punt
+    # for "I don't know, here's a generic binary MIME type.
+    # In some cases that is has indicated a bug in File::MMagic,
+    # but it's a generally worthless response for identifying the file type.
+    # so, we throw away the response in that case. The uploaded MIME type
+    # will be used instead later, if present
+    $fm_mt = undef if ($fm_mt eq 'application/octet-stream');
+
+
 	## fetch mime type universally (or close) 
 	my $uploaded_mt = _get_upload_mime_type($self);
 
-   # XXX perhaps this should be in a global variable so it's easier
-   # for other apps to change the defaults;	
-   $params->{mime_types} ||= [qw!image/jpeg  image/pjpeg image/gif image/png!];
-   my %allowed_types = map { $_ => 1 } @{ $params->{mime_types} };
-
    # try the File::MMagic, then the uploaded field, then return undef we find neither
    my $mt = ($fm_mt || $uploaded_mt) or return undef;
 
@@ -146,9 +150,23 @@ sub valid_file_format {
    $info = { %$info, mime_type => $mt, extension => ".$ext" };
    $self->meta($field,$info);
 
-   return $allowed_types{$mt};
+   return _is_allowed_type($mt, $params);
 }
 
+## Returns true if the passed-in mime-type matches our allowed types
+sub _is_allowed_type {
+    my $mt     = shift;
+    my $params = shift;
+
+    # XXX perhaps this should be in a global variable so it's easier
+    # for other apps to change the defaults;
+    $params->{mime_types} ||= [qw!image/jpeg image/pjpeg image/gif image/png!];
+    my %allowed_types = map { $_ => 1 } @{ $params->{mime_types} };
+
+    return $allowed_types{lc $mt};
+} 
+
+
 sub valid_image_max_dimensions {
 	my $self = shift;
 	$self->isa('Data::FormValidator::Results') ||
@@ -289,7 +307,7 @@ sub _get_upload_fh
 	my $q	  = $self->get_input_data;
 	my $field = $self->get_current_constraint_field;
 
-	## CGI::Simple object processing (slighly different from others)
+	## CGI::Simple object processing (slightly different from others)
 	if ($q->isa('CGI::Simple')) {
 		## get filename 
 		my $fn = $q->param($field);
@@ -318,8 +336,8 @@ sub _get_upload_fh
 	}
 
 
-	## only CGI.pm just incase for wierd subclasses
-	## generic data object (or CGI), CGi.pm has incomplete fh's nice huh
+	## only CGI.pm just in case for weird subclasses
+	## generic data object (or CGI), CGI.pm has incomplete fh's nice huh
 	if ($q->isa('CGI')) {
 		use IO::File;
 		my $fh = $q->upload($field);
@@ -422,7 +440,7 @@ available, and a case-insensitive version of the file extension otherwise. By
 default, it tries to validate JPEG, GIF and PNG images. The params are:
 
  optional hash reference of parameters. A key named I<mime_types> points to
- array refererences of valid values.
+ array references of valid values.
 
    file_format( mime_types => [qw!image/jpeg image/gif image/png!] );
 
